### R code from vignette source 'palmtree.Rnw'

###################################################
### code chunk number 1: palmtree.Rnw:131-132 (eval = FALSE)
###################################################
## page(palmtree)


###################################################
### code chunk number 2: palmtree.Rnw:137-138 (eval = FALSE)
###################################################
## palmtree(formula, data)


###################################################
### code chunk number 3: sim-figure
###################################################
library("partykit")

fig1 <- party(
  partynode(1L,
    split = partysplit(1L, breaks = 0),
    kids = list(
      partynode(2L, info = expression(beta[1])),
      partynode(3L,
        split = partysplit(2L, breaks = 0),
        kids = list(
          partynode(4L, info = expression(beta[2])),
          partynode(5L, info = expression(beta[3]))
    )
      )
    )
  ),
  data.frame(z1 = numeric(0), z2 = numeric(0))
)
plot(fig1, drop = TRUE, ip_args = list(id = FALSE),
  tp_args = list(FUN = identity, width = 9, id = FALSE)) 


###################################################
### code chunk number 4: sim-dgp
###################################################
dgp <- function() {
  
  nobs <- 1000
  npc <- 30
  
  ## patient characteristics
  x <- mvtnorm::rmvnorm(nobs, mean = rep(0, npc), 
                        sigma = diag(1 - 0.2, npc) + 0.2)
  colnames(x) <- paste0("x", 1:npc)
  d <- as.data.frame(x)
  
  ## treatment xV
  d$xV<- rbinom(nobs, size = 1, prob = 0.5)
  
  ## error term
  d$err <- rnorm(nobs, mean = 0, sd = 1.5)
  
  ## predictive and prognostic factors
  which_pred <- 1:2  
  which_prog <- 3:4
  
  ## define subgroups
  rules <- t(t(x[, which_pred]) > c(0, 0))
  d$group <- 1
  d$group[rules[, 1] == 1] <- 2
  d$group[rowSums(rules) == 2] <- 3
  d$group <- as.factor(d$group)
  
  ## response function mu
  eff_trt <- c(-0.375, 0.125, 0.625)
  modelmat <- model.matrix(~ group - 1, data = d)
  d$trt_effect <- modelmat %*% eff_trt 
  d$mu0 <- as.vector(x[ , which_prog] %*% c(1, 1))
  d$mu1 <- as.vector(d$mu0 + d$trt_effect)
  idmu <- cbind(seq_len(nrow(d)), d$xV + 1)
  d$mu <- d[ , c("mu0", "mu1")][idmu]
  
  ## outcome y
  d$y <- d$mu + d$err
  
  d$xV <- factor(d$xV)
  return(d)
}


###################################################
### code chunk number 5: sim-sim
###################################################
set.seed(123)
data_sim <- dgp()


###################################################
### code chunk number 6: sim-palmtree
###################################################
x_sim <- paste0("x", 1:30) 
fmla_sim <- as.formula(
  paste("y ~ xV | x3 + x4 |", 
        paste(x_sim, collapse = " + "))
)

library("palmtree")
(palmtree_sim <- palmtree(fmla_sim, data = data_sim))

plot(palmtree_sim)


###################################################
### code chunk number 7: sim-repeat
###################################################
set.seed(222)
for(i in 1:3) {
  data_sim_i <- dgp()
  palmtree_sim_i <- palmtree(fmla_sim, data = data_sim_i)
  plot(palmtree_sim_i)
}


###################################################
### code chunk number 8: palmtree.Rnw:315-324
###################################################
set.seed(222)
for(i in 1:3) {
  data_sim_i <- dgp()
  palmtree_sim_i <- palmtree(fmla_sim, data = data_sim_i)
  pdf(file = paste0("vignette_sim-repeat-", i, ".pdf"),
      width = 4, height = 5.5)
  plot(palmtree_sim_i)
  dev.off()
}


###################################################
### code chunk number 9: math
###################################################
data("MathExam14W", package = "psychotools")

## scale points achieved to [0, 100] percent
MathExam14W$tests <- 100 * MathExam14W$tests/26
MathExam14W$pcorrect <- 100 * MathExam14W$nsolved/13

## select variables to be used
MathExam <- MathExam14W[ , c("pcorrect", "group", "tests", "study",
                             "attempt", "semester", "gender")]


###################################################
### code chunk number 10: math-summary
###################################################
summary(MathExam)


###################################################
### code chunk number 11: math-palmtree
###################################################
(palmtree_math <- palmtree(pcorrect ~ group | tests | tests + study +
                            attempt + semester + gender, data = MathExam))


###################################################
### code chunk number 12: math-palmtree-1
###################################################
plot(palmtree_math)


###################################################
### code chunk number 13: palmtree.Rnw:386-389
###################################################
coef(palmtree_math)
coef(palmtree_math$palm)
coef(palmtree_math$tree)


###################################################
### code chunk number 14: palmtree.Rnw:392-394
###################################################
(palmmod1 <- lm(pcorrect ~ .tree + group:.tree + tests, 
                data = palmtree_math$data))


###################################################
### code chunk number 15: palmtree.Rnw:397-399
###################################################
(palmmod2 <- lm(pcorrect ~ 0 + .tree + group:.tree + tests, 
                data = palmtree_math$data))


###################################################
### code chunk number 16: set (eval = FALSE)
###################################################
## palmtree(formula, data, weights = NULL, family = NULL,
##          lmstart = NULL, abstol = 0.001, maxit = 100, 
##          dfsplit = TRUE, verbose = FALSE, plot = FALSE, ...)


###################################################
### code chunk number 17: palmtree.Rnw:431-432 (eval = FALSE)
###################################################
## lm(pcorrect ~ group + tests, data = MathExam)


###################################################
### code chunk number 18: palmtree.Rnw:475-478 (eval = FALSE)
###################################################
## lm(y ~ x3 + x4 +
##      xV * I(x1 > 0 & x2 <= 0) + 
##      xV * I(x1 > 0 & x2 > 0), data = data_sim)


###################################################
### code chunk number 19: palmtree.Rnw:482-483 (eval = FALSE)
###################################################
## palmtree(y ~ xV | x3 + x4 | x1 + x2, data = data_sim)


###################################################
### code chunk number 20: palmtree.Rnw:488-492 (eval = FALSE)
###################################################
## palmtree(y ~ xV | x3 + x4 | x1 + x2 + x5 + x6 + x7 + x8 + x9 + 
##            x10 + x11 + x12 + x13 + x14 + x15 + x16 + x17 + x18 + x19 + 
##            x20 + x21 + x22 + x23 + x24 + x25 + x26 + x27 + x28 + x29 + 
##            x30, data = data_sim)


###################################################
### code chunk number 21: palmtree.Rnw:497-501 (eval = FALSE)
###################################################
## lmtree(y ~ xV + x3 + x4 | x1 + x2 + x5 + x6 + x7 + x8 + x9 + 
##            x10 + x11 + x12 + x13 + x14 + x15 + x16 + x17 + x18 + x19 + 
##            x20 + x21 + x22 + x23 + x24 + x25 + x26 + x27 + x28 + x29 + 
##            x30, data = data_sim)


###################################################
### code chunk number 22: palmtree.Rnw:505-509 (eval = FALSE)
###################################################
## palmtree(y ~ xV | x3 + x4 | x1 + x2 + x3 + x4 + x5 + x6 + x7 + x8 + x9 + 
##            x10 + x11 + x12 + x13 + x14 + x15 + x16 + x17 + x18 + x19 + 
##            x20 + x21 + x22 + x23 + x24 + x25 + x26 + x27 + x28 + x29 + 
##            x30, data = data_sim)


###################################################
### code chunk number 23: palmtree.Rnw:512-516 (eval = FALSE)
###################################################
## lmtree(y ~ xV | x1 + x2 + x3 + x4 + x5 + x6 + x7 + x8 + x9 + 
##          x10 + x11 + x12 + x13 + x14 + x15 + x16 + x17 + x18 + x19 + 
##          x20 + x21 + x22 + x23 + x24 + x25 + x26 + x27 + x28 + x29 + 
##          x30, data = data_sim)


